import pandas as pd
from uniprotparser.betaparser import UniprotSequence

curtain_ptm_de_form = {
    "_reverseFoldChange": False,
    "_comparisonSelect": "",
    "_comparison": "",
    "_primaryIDs": "",
    "_geneNames": "",
    "_foldChange": "",
    "_transformFC": False,
    "_significant": "",
    "_transformSignificant": False,
    "_accession": "",
    "_position": "",
    "_positionPeptide": "",
    "_peptideSequence": "",
    "_score": "",

}

curtain_base_de_form = {
    "_reverseFoldChange": False,
    "_comparisonSelect": [],
    "_comparison": "",
    "_primaryIDs": "",
    "_geneNames": "",
    "_foldChange": "",
    "_transformFC": False,
    "_significant": "",
    "_transformSignificant": False,
}

curtain_base_raw_form = {
    "_primaryIDs": "",
    "_samples": [],
}

curtain_base_input_file = {
    "df": "",
    "filename": "",
    "other": {},
    "originalFile": ""
}

curtain_base_project_form = {
    "title": "",
    "projectDescription": "",
    "organisms": [{"name": ""}],
    "organismParts": [{"name": ""}],
    "cellTypes": [{"name": ""}],
    "diseases": [{"name": ""}],
    "sampleProcessingProtocol": "",
    "dataProcessingProtocol": "",
    "identifiedPTMStrings": [{"name": ""}],
    "instruments": [{"name": "", "cvLabel": "MS"}],
    "msMethods": [{"name": ""}],
    "projectTags": [{"name": ""}],
    "quantificationMethods": [{"name": ""}],
    "species": [{"name": ""}],
    "sampleAnnotations": {},
    "_links": {"datasetFtpUrl": {"href": ""}, "files": {"href": ""}, "self": {"href": ""}},
    "affiliations": [{"name": ""}],
    "hasLink": False,
    "authors": [],
    "accession": "",
    "softwares": [{"name": ""}],
}



curtain_base_settings = {
    "fetchUniprot": True,
    "sampleMap": {},
    "barchartColorMap": {},
    "pCutoff": 0.05,
    "log2FCCutoff": 0.6,
    "description": "",
    "uniprot": False,
    "colorMap": {},
    "backGroundColorGrey": False,
    "selectedComparison": [],
    "version": 2,
    "currentID": "",
    "fdrCurveText": "",
    "fdrCurveTextEnable": False,
    "prideAccession": "",
    "project": curtain_base_project_form,
    "sampleOrder": {},
    "sampleVisible": {},
    "conditionOrder": [],
    "volcanoAxis": {
        "minX": None,
        "maxX": None,
        "minY": None,
        "maxY": None
    },
    "textAnnotation": {},
    "volcanoPlotTitle": "",
    "visible": {},
    "defaultColorList": [
        "#fd7f6f",
        "#7eb0d5",
        "#b2e061",
        "#bd7ebe",
        "#ffb55a",
        "#ffee65",
        "#beb9db",
        "#fdcce5",
        "#8bd3c7",
    ],
    "scatterPlotMarkerSize": 10,
    "rankPlotColorMap": {},
    "rankPlotAnnotation": {},
    "legendStatus": {},
    "stringDBColorMap": {
        "Increase": "#8d0606",
        "Decrease": "#4f78a4",
        "In dataset": "#ce8080",
        "Not in dataset": "#676666"
    },
    "interactomeAtlasColorMap": {
        "Increase": "#a12323",
        "Decrease": "#16458c",
        "HI-Union": "rgba(82,110,194,0.96)",
        "Literature": "rgba(181,151,222,0.96)",
        "HI-Union and Literature": "rgba(222,178,151,0.96)",
        "Not found": "rgba(25,128,128,0.96)",
        "No change": "rgba(47,39,40,0.96)",
    },
    "proteomicsDBColor": "#ff7f0e",
    "networkInteractionSettings": {
        "Increase": "rgba(220,169,0,0.96)",
        "Decrease": "rgba(220,0,59,0.96)",
        "StringDB": "rgb(206,128,128)",
        "No change": "rgba(47,39,40,0.96)",
        "Not significant": "rgba(255,255,255,0.96)",
        "Significant": "rgba(252,107,220,0.96)",
        "InteractomeAtlas": "rgb(73,73,101)",
    },
    "plotFontFamily": "Arial",
    "networkInteractionData": [],
    "enrichrGeneRankMap": {},
    "enrichrRunList": [],
    "customVolcanoTextCol": ""
}

curtain_ptm_settings = {
    "fetchUniprot": True,
    "sampleMap": {},
    "barchartColorMap": {},
    "pCutoff": 0.05,
    "log2FCCutoff": 0.6,
    "description": "",
    "uniprot": False,
    "colorMap": {},
    "backGroundColorGrey": False,
    "selectedComparison": [],
    "version": 2,
    "currentID": "",
    "fdrCurveText": "",
    "fdrCurveTextEnable": False,
    "prideAccession": "",
    "project": curtain_base_project_form,
    "sampleOrder": {},
    "sampleVisible": {},
    "conditionOrder": [],
    "volcanoAxis": {
        "minX": None,
        "maxX": None,
        "minY": None,
        "maxY": None
    },
    "textAnnotation": {},
    "volcanoPlotTitle": "",
    "visible": {},
    "defaultColorList": [
        "#fd7f6f",
        "#7eb0d5",
        "#b2e061",
        "#bd7ebe",
        "#ffb55a",
        "#ffee65",
        "#beb9db",
        "#fdcce5",
        "#8bd3c7",
    ],
    "scatterPlotMarkerSize": 10,
    "rankPlotColorMap": {},
    "rankPlotAnnotation": {},
    "legendStatus": {},
    "stringDBColorMap": {
        "Increase": "#8d0606",
        "Decrease": "#4f78a4",
        "In dataset": "#ce8080",
        "Not in dataset": "#676666"
    },
    "interactomeAtlasColorMap": {
        "Increase": "#a12323",
        "Decrease": "#16458c",
        "HI-Union": "rgba(82,110,194,0.96)",
        "Literature": "rgba(181,151,222,0.96)",
        "HI-Union and Literature": "rgba(222,178,151,0.96)",
        "Not found": "rgba(25,128,128,0.96)",
        "No change": "rgba(47,39,40,0.96)",
    },
    "proteomicsDBColor": "#ff7f0e",
    "networkInteractionSettings": {
        "Increase": "rgba(220,169,0,0.96)",
        "Decrease": "rgba(220,0,59,0.96)",
        "StringDB": "rgb(206,128,128)",
        "No change": "rgba(47,39,40,0.96)",
        "Not significant": "rgba(255,255,255,0.96)",
        "Significant": "rgba(252,107,220,0.96)",
        "InteractomeAtlas": "rgb(73,73,101)",
    },
    "plotFontFamily": "Arial",
    "networkInteractionData": [],
    "enrichrGeneRankMap": {},
    "enrichrRunList": [],
    "customVolcanoTextCol": "",
    "variantCorrection": {},
    "customSequences": {}
}

curtain_base_payload = {
    "raw": "",
    "rawForm": curtain_base_raw_form,
    "differentialForm": curtain_base_de_form,
    "processed": "",
    "password": "",
    "selections": [],
    "selectionsMap": {},
    "selectionsName": [],
    "settings": curtain_base_settings,
    "fetchUniprot": True,
    "annotatedData": {},
}

def read_fasta(fasta_file: str) -> pd.DataFrame:
    fasta_dict = {}
    with open(fasta_file, 'r') as f:
        current_acc = ""
        count = 0
        for line in f:
            if line.startswith('>'):
                count += 1
                acc = UniprotSequence(line.strip(), True)

                if acc.accession:
                    fasta_dict[str(acc)] = ""
                    current_acc = str(acc)
                else:
                    fasta_dict[line.strip().replace(">", "")] = ""
                    current_acc = line.strip().replace(">", "")

            else:
                fasta_dict[current_acc] += line.strip()


    return pd.DataFrame([[k, fasta_dict[k]] for k in fasta_dict], columns=["Entry", "Sequence"])



import io

import click
import pandas as pd
from uniprotparser.betaparser import UniprotSequence, UniprotParser
import re
from curtainutils.common import read_fasta
reg_pattern = re.compile("_\w(\d+)_")
protein_name_pattern = re.compile("(\w+_\w+)")
def lambda_function_for_spectronaut_ptm(row: pd.Series, index_col: str, peptide_col: str, fasta_df: pd.DataFrame) -> pd.Series:
    d = row[index_col].split("_")
    row["Position"] = int(d[-2][1:])
    matched_acc_row = fasta_df[fasta_df["Entry"].str.contains(row["UniprotID"])]
    reformat_seq = row[peptide_col].split(";")[0].upper()
    if len(matched_acc_row) > 0:
        for i2, row2 in matched_acc_row.iterrows():
            row2["PeptideSequence"] = reformat_seq[:len(reformat_seq)-2]
            seq = row2["Sequence"]
            try:
                peptide_position = seq.index(row2["PeptideSequence"])
            except ValueError:
                peptide_position = seq.replace("I", "L").index(
                    row2["PeptideSequence"].replace("I", "L"))
                row["Comment"] = "I replaced by L"
            if peptide_position >= -1:
                position_in_peptide = row["Position"] - peptide_position
                row["Position.in.peptide"] = position_in_peptide
                row["Variant"] = row2["Entry"]
                sequence_window = ""
                if row["Position"] - 1 - 10 >= 0:
                    sequence_window += seq[row["Position"] - 1 - 10:row["Position"] - 1]
                else:
                    sequence_window += seq[:row["Position"] - 1]
                    if len(sequence_window) < 10:
                        sequence_window = "_" * (10 - len(sequence_window)) + sequence_window
                sequence_window += seq[row["Position"] - 1]
                if row["Position"] + 10 <= len(seq):
                    sequence_window += seq[row["Position"]:row["Position"] + 10]
                else:
                    sequence_window += seq[row["Position"]:]
                    if len(sequence_window) < 21:
                        sequence_window += "_" * (21 - len(sequence_window))

                row["Sequence.window"] = sequence_window
                break
    return row

@click.command()
@click.option("--file_path", "-f", help="Path to the file to be processed")
@click.option("--index_col", "-i", help="Name of the index column", default="PTM_collapse_key")
@click.option("--peptide_col", "-p", help="Name of the peptide column", default="PEP.StrippedSequence")
@click.option("--output_file", "-o", help="Path to the output file")
@click.option("--fasta_file", "-a", help="Path to the fasta file")
def process_spectronaut_ptm(
        file_path: str,
        index_col: str,
        peptide_col: str,
        output_file: str,
        fasta_file: str = ""):
    df = pd.read_csv(file_path, sep="\t")
    df["UniprotID"] = df[index_col].apply(lambda x: str(UniprotSequence(x, parse_acc=True)) if UniprotSequence(x, parse_acc=True).accession else x)
    if fasta_file:
        fasta_df = read_fasta(fasta_file)
    else:
        parser = UniprotParser(columns="accession,id,sequence", include_isoform=True)
        fasta_df = []
        for i in parser.parse(df["UniprotID"].unique().tolist()):
            fasta_df.append(pd.read_csv(io.StringIO(i), sep="\t"))
        if len(fasta_df) == 1:
            fasta_df = fasta_df[0]
        else:
            fasta_df = pd.concat(fasta_df, ignore_index=True)
    # peptide_col="PEP.StrippedSequence"
    # index_col="PTM_collapse_key"
    df = df.apply(lambda x: lambda_function_for_spectronaut_ptm(x, index_col, peptide_col, fasta_df), axis=1)
    df.to_csv(output_file, sep="\t", index=False)

@click.command()
@click.option("--file_path", "-f", help="Path to the file to be processed")
@click.option("--index_col", "-i", help="Name of the index column", default="PTM_collapse_key")
@click.option("--peptide_col", "-p", help="Name of the peptide column", default="PEP.StrippedSequence")
@click.option("--output_file", "-o", help="Path to the output file")
@click.option("--fasta_file", "-a", help="Path to the fasta file")
def main(file_path: str, index_col: str, peptide_col: str, output_file: str, fasta_file: str):
    process_spectronaut_ptm(file_path, index_col, peptide_col, output_file, fasta_file)


import io

import click
import pandas as pd
from uniprotparser.betaparser import UniprotSequence, UniprotParser

from curtainutils.common import read_fasta
import re

reg_positon_residue = re.compile("_(\w)(\d+)")

def lambda_function_for_msfragger_ptm_single_site(row: pd.Series, index_col: str, peptide_col: str, fasta_df: pd.DataFrame) -> pd.Series:
    match = reg_positon_residue.search(row[index_col])
    print(f"Processing {row[index_col]}")
    if match:
        position = int(match.group(2))
        row["Position"] = position
        row["Residue"] = match.group(1)
        matched_acc_row = fasta_df[fasta_df["Entry"].str.contains(row["PrimaryID"])]
        if len(matched_acc_row) > 0:
            for i2, row2 in matched_acc_row.iterrows():
                seq = row2["Sequence"]
                peptide_seq = row[peptide_col].split(";")[0].upper()
                try:
                    peptide_position = seq.index(peptide_seq)
                except ValueError:
                    peptide_position = seq.replace("I", "L").index(
                        peptide_seq.replace("I", "L"))
                    row["Comment"] = "I replaced by L"
                if peptide_position >= -1:

                    position_in_peptide = position - peptide_position
                    row["Position.in.peptide"] = position_in_peptide
                    row["Variant"] = row2["Entry"]
                    sequence_window = ""
                    if row["Position"] - 1 - 10 >= 0:
                        sequence_window += seq[row["Position"] - 1 - 10:row["Position"] - 1]
                    else:
                        sequence_window += seq[:row["Position"] - 1]
                        if len(sequence_window) < 10:
                            sequence_window = "_" * (10 - len(sequence_window)) + sequence_window
                    sequence_window += seq[row["Position"] - 1]
                    if row["Position"] + 10 <= len(seq):
                        sequence_window += seq[row["Position"]:row["Position"] + 10]
                    else:
                        sequence_window += seq[row["Position"]:]
                        if len(sequence_window) < 21:
                            sequence_window += "_" * (21 - len(sequence_window))

                    row["Sequence.window"] = sequence_window
                    break

    return row


def process_msfragger_ptm_single_site(file_path: str, index_col: str, peptide_col: str, output_file: str, fasta_file: str = ""):
    df = pd.read_csv(file_path, sep="\t")

    df["PrimaryID"] = df[index_col].apply(lambda x: str(UniprotSequence(x, parse_acc=True)) if UniprotSequence(x, parse_acc=True).accession else x)
    if fasta_file:
        fasta_df = read_fasta(fasta_file)
    else:
        parser = UniprotParser(columns="accession,id,sequence", include_isoform=True)
        fasta_df = []
        for i in parser.parse(df["PrimaryID"].unique().tolist()):
            fasta_df.append(pd.read_csv(io.StringIO(i), sep="\t"))
        if len(fasta_df) == 1:
            fasta_df = fasta_df[0]
        else:
            fasta_df = pd.concat(fasta_df, ignore_index=True)
    df = df.apply(lambda x: lambda_function_for_msfragger_ptm_single_site(x, index_col, peptide_col, fasta_df), axis=1)
    df.to_csv(output_file, sep="\t", index=False)


@click.command()
@click.option("--file_path", "-f", help="Path to the file to be processed")
@click.option("--index_col", "-i", help="Name of the index column", default="Index")
@click.option("--peptide_col", "-p", help="Name of the peptide column", default="Peptide")
@click.option("--output_file", "-o", help="Path to the output file")
@click.option("--fasta_file", "-a", help="Path to the fasta file")
def main(file_path: str, index_col: str, peptide_col: str, output_file: str, fasta_file: str):
    process_msfragger_ptm_single_site(file_path, index_col, peptide_col, output_file, fasta_file)



import json
from copy import deepcopy
from typing import List

import pandas as pd
import requests
import seaborn as sns
from matplotlib import pyplot as plt

from curtainutils.common import curtain_base_payload


class CurtainClient:
    def __init__(self, base_url: str):
        self.base_url = base_url

    def post_curtain_session(self, payload: dict, file: dict, **kwargs) -> str:
        file = {'file': ('curtain-settings.json', json.dumps(file))}
        r = requests.post(f"{self.base_url}/curtain/", data=payload, files=file)
        if r.status_code == 200:
            return r.json()["link_id"]
        else:
            raise ValueError(r.text)

    def curtain_stats_summary(self, last_n_days: int = 30):
        req = requests.get(f"{self.base_url}/stats/summary/{last_n_days}/")
        data = req.json()
        session_download_per_day = pd.DataFrame(data["session_download_per_day"])
        session_download_per_day.sort_values(by="date", inplace=True)
        session_created_per_day = pd.DataFrame(data["session_created_per_day"])
        session_created_per_day.sort_values(by="date", inplace=True)
        fig, ax = plt.subplots(2, 1, figsize=(20, 10))
        sns.barplot(data=session_download_per_day, x="date", y="downloads", ax=ax[0])
        sns.barplot(data=session_created_per_day, x="date", y="count", ax=ax[1])
        ax[0].set_title("Curtain Session Download per day")
        ax[1].set_title("Curtain Session Creation per day")

        #rotate x axis labels 90 degrees
        for ax in fig.axes:
            plt.sca(ax)
            plt.xticks(rotation=90)

        fig.tight_layout()
        plt.show()

    def download_curtain_session(self, link_id: str):
        req = requests.get(f"{self.base_url}/curtain/{link_id}/download/?token=/")
        if req.status_code == 200:
            data = req.json()
            if "url" in data:
                result = requests.get(data["url"])
                if result.status_code == 200:
                    return result.json()
            else:
                return data
        return None

    def download_sessions_list(self, url_list: List[str]):
        for i in url_list:
            result = self.download_curtain_session(i)
            if result:
                with open(f"{i}_de.txt", "wt") as f:
                    f.write(result["processed"])
                with open(f"{i}_raw.txt", "wt") as f:
                    f.write(result["raw"])


    def create_curtain_session_payload(
            self,
            de_file: str,
            raw_file: str,
            fc_col: str,
            transform_fc: bool,
            transform_significant: bool,
            reverse_fc: bool,
            p_col: str,
            comp_col: str,
            comp_select: List[str],
            primary_id_de_col: str,
            primary_id_raw_col:str,
            sample_cols: List[str], **kwargs) -> dict:
        payload = deepcopy(curtain_base_payload)
        with open(de_file, "rt") as f, open(raw_file, "rt") as f2:
            payload["processed"] = f.read()
            payload["raw"] = f2.read()

        payload["differentialForm"]["_foldChange"] = fc_col
        payload["differentialForm"]["_significant"] = p_col
        payload["differentialForm"]["_comparison"] = comp_col
        payload["differentialForm"]["_comparisonSelect"] = comp_select
        payload["differentialForm"]["_primaryIDs"] = primary_id_de_col
        payload["rawForm"]["_primaryIDs"] = primary_id_raw_col
        payload["rawForm"]["_samples"] = sample_cols

        assert type(transform_fc) == bool
        assert type(transform_significant) == bool
        assert type(reverse_fc) == bool

        payload["differentialForm"]["_transformFC"] = transform_fc
        payload["differentialForm"]["_transformSignificant"] = transform_significant
        payload["differentialForm"]["_reverseFoldChange"] = reverse_fc

        if payload["differentialForm"]["_comparison"] == "":
            payload["differentialForm"]["_comparison"] = "CurtainSetComparison"

        if len(payload["differentialForm"]["_comparisonSelect"]) == 0:
            payload["differentialForm"]["_comparisonSelect"] = ["1"]

        assert len(sample_cols) > 0
        conditions = []
        color_position = 0
        sample_map = {}
        color_map = {}
        for i in sample_cols:
            name_array = i.split(".")
            replicate = name_array[-1]
            condition = ".".join(name_array[:-1])
            if condition not in conditions:
                conditions.append(condition)
                if color_position >= len(payload["settings"]["defaultColorList"]):
                    color_position = 0
                color_map[condition] = payload["settings"]["defaultColorList"][color_position]
                color_position += 1
            if condition not in payload["settings"]["sampleOrder"]:
                payload["settings"]["sampleOrder"][condition] = []
            if i not in payload["settings"]["sampleOrder"][condition]:
                payload["settings"]["sampleOrder"][condition].append(i)
            if i not in payload["settings"]["sampleVisible"]:
                payload["settings"]["sampleVisible"][i] = True

            sample_map[i] = {"condition": condition, "replicate": replicate, "name": i}
        payload["settings"]["sampleMap"] = sample_map
        payload["settings"]["colorMap"] = color_map
        payload["settings"]["conditionOrder"] = conditions

        return payload

    def create_curtain_ptm_session_payload(
            self,
            de_file: str,
            raw_file: str,
            fc_col: str,
            transform_fc: bool,
            transform_significant: bool,
            reverse_fc: bool,
            p_col: str,
            comp_col: str,
            comp_select: List[str],
            primary_id_de_col: str,
            primary_id_raw_col:str,
            sample_cols: List[str],
            peptide_col: str,
            acc_col: str,
            position_col: str,
            position_in_peptide_col: str,
            sequence_window_col: str,
            score_col: str,
            **kwargs) -> dict:
        payload = deepcopy(curtain_base_payload)
        with open(de_file, "rt") as f, open(raw_file, "rt") as f2:
            payload["processed"] = f.read()
            payload["raw"] = f2.read()

        payload["differentialForm"]["_foldChange"] = fc_col
        payload["differentialForm"]["_significant"] = p_col
        payload["differentialForm"]["_comparison"] = comp_col
        payload["differentialForm"]["_comparisonSelect"] = comp_select
        payload["differentialForm"]["_primaryIDs"] = primary_id_de_col
        payload["differentialForm"]["_peptideSequence"] = peptide_col
        payload["differentialForm"]["_accession"] = acc_col
        payload["differentialForm"]["_position"] = position_col
        payload["differentialForm"]["_positionPeptide"] = position_in_peptide_col
        payload["differentialForm"]["_score"] = score_col
        payload["differentialForm"]["_sequenceWindow"] = sequence_window_col
        payload["rawForm"]["_primaryIDs"] = primary_id_raw_col
        payload["rawForm"]["_samples"] = sample_cols

        assert type(transform_fc) == bool
        assert type(transform_significant) == bool
        assert type(reverse_fc) == bool

        payload["differentialForm"]["_transformFC"] = transform_fc
        payload["differentialForm"]["_transformSignificant"] = transform_significant
        payload["differentialForm"]["_reverseFoldChange"] = reverse_fc

        if payload["differentialForm"]["_comparison"] == "":
            payload["differentialForm"]["_comparison"] = "CurtainSetComparison"

        if len(payload["differentialForm"]["_comparisonSelect"]) == 0:
            payload["differentialForm"]["_comparisonSelect"] = ["1"]

        assert len(sample_cols) > 0
        conditions = []
        color_position = 0
        sample_map = {}
        color_map = {}
        for i in sample_cols:
            name_array = i.split(".")
            replicate = name_array[-1]
            condition = ".".join(name_array[:-1])
            if condition not in conditions:
                conditions.append(condition)
                if color_position >= len(payload["settings"]["defaultColorList"]):
                    color_position = 0
                color_map[condition] = payload["settings"]["defaultColorList"][color_position]
                color_position += 1
            if condition not in payload["settings"]["sampleOrder"]:
                payload["settings"]["sampleOrder"][condition] = []
            if i not in payload["settings"]["sampleOrder"][condition]:
                payload["settings"]["sampleOrder"][condition].append(i)
            if i not in payload["settings"]["sampleVisible"]:
                payload["settings"]["sampleVisible"][i] = True

            sample_map[i] = {"condition": condition, "replicate": replicate, "name": i}
        payload["settings"]["sampleMap"] = sample_map
        payload["settings"]["colorMap"] = color_map
        payload["settings"]["conditionOrder"] = conditions

        return payload

    def create_curtain_payload(
            self,
            de_file: str,
            raw_file: str,
            fc_col: str,
            transform_fc: bool,
            transform_significant: bool,
            reverse_fc: bool,
            p_col: str,
            comp_col: str,
            comp_select: List[str],
            primary_id_de_col: str,
            primary_id_raw_col:str,
            sample_cols: List[str],
            peptide_col: str = "",
            acc_col: str = "",
            position_col: str = "",
            position_in_peptide_col: str = "",
            sequence_window_col: str = "",
            score_col: str = "",
            **kwargs) -> dict:
        if peptide_col == "" and acc_col == "" and position_col == "" and position_in_peptide_col == "" and sequence_window_col == "" and score_col == "":
            return self.create_curtain_session_payload(de_file, raw_file, fc_col, transform_fc, transform_significant, reverse_fc, p_col, comp_col, comp_select, primary_id_de_col, primary_id_raw_col, sample_cols, **kwargs)
        else:
            return self.create_curtain_ptm_session_payload(de_file, raw_file, fc_col, transform_fc, transform_significant, reverse_fc, p_col, comp_col, comp_select, primary_id_de_col, primary_id_raw_col, sample_cols, peptide_col, acc_col, position_col, position_in_peptide_col, sequence_window_col, score_col, **kwargs)

